@@ -28,6 +28,9 @@
 #define DEST 32
 #define NAME trunc
 
+#include <float.h>
+#include <fenv.h>
+
 #include "dfpacc.h"
 #include "convert.h"
 #include "convert_helpers.h"
@@ -38,22 +41,53 @@ CONVERT_WRAPPER(
 	_Decimal64 a_norm;
 	long long mant;
 	int exp, sexp;
-	
+
 	a_norm = getmantandexpd64 (a, &exp, 16, 1e16DD);
-	
+
 	/* Check for values that would overflow the exponent table, which
 	   would be obvious overflow and underflow.  */
-	if (exp > 39)		/* Obvious overflow.  */
+	if (exp > FLT_MAX_10_EXP)		/* Obvious overflow.  */
 	  {
 	    if (DFP_EXCEPTIONS_ENABLED)
 	      DFP_HANDLE_EXCEPTIONS (FE_OVERFLOW|FE_INEXACT);
-	    return SIGNBIT(a) ? -INFINITY : INFINITY;
+
+	    switch (fegetround())
+	      {
+	        case FE_TOWARDZERO:
+	          return SIGNBIT(a) ? -FLT_MAX : FLT_MAX;
+	        case FE_DOWNWARD:
+	          return SIGNBIT(a) ? -INFINITY : FLT_MAX;
+	        case FE_UPWARD:
+	          return SIGNBIT(a) ? -FLT_MAX : INFINITY;
+	        case FE_TONEAREST:
+	        default:
+	          return SIGNBIT(a) ? -INFINITY : INFINITY;
+	      }
 	  }
-	else if (exp < -39)	/* Obvious underflow.  */
+	else if (exp < -POWOF10_MIN_DENORM_FLT_EXP)  /* Obvious underflow.  */
 	  {
 	    if (DFP_EXCEPTIONS_ENABLED)
 	      DFP_HANDLE_EXCEPTIONS (FE_UNDERFLOW|FE_INEXACT);
-	    return SIGNBIT(a) ? -0.0 : 0.0;
+
+	    switch (fegetround())
+	      {
+	        case FE_TONEAREST:
+	          mant = llabs(a_norm);
+	          if (exp < -POWOF10_MIN_DENORM_FLT_EXP
+	              || ((exp == -POWOF10_MIN_DENORM_FLT_EXP)
+	              && (mant >= (POWOF10_MIN_DENORM_FLT_MAN/2LL))))
+	            return SIGNBIT(a) ? -0.0 : 0.0;
+	          else
+	            return SIGNBIT(a) ? -__FLT_DENORM_MIN__ :
+	                                 __FLT_DENORM_MIN__;
+	        case FE_DOWNWARD:
+	          return SIGNBIT(a) ? -__FLT_DENORM_MIN__ : 0.0;
+	        case FE_UPWARD:
+	          return SIGNBIT(a) ? -0.0 : __FLT_DENORM_MIN__;
+	        case FE_TOWARDZERO:
+	        default:
+	          return  SIGNBIT(a) ? -0.0 : 0.0;
+	      }
 	  }
 
 	mant = a_norm;			/* 16 digits of mantissa.  */
