@@ -28,6 +28,9 @@
 #define DEST 64
 #define NAME trunc
 
+#include <float.h>
+#include <fenv.h>
+
 #include "dfpacc.h"
 #include "convert.h"
 
@@ -48,13 +51,44 @@ CONVERT_WRAPPER(
 	  {
 	    if (DFP_EXCEPTIONS_ENABLED)
 	      DFP_HANDLE_EXCEPTIONS (FE_OVERFLOW|FE_INEXACT);
-	    return SIGNBIT(a) ? -INFINITY : INFINITY;
+
+	    switch (fegetround())
+	      {
+	        case FE_TOWARDZERO:
+	          return SIGNBIT(a) ? -DBL_MAX : DBL_MAX;
+	        case FE_DOWNWARD:
+	          return SIGNBIT(a) ? -INFINITY : DBL_MAX;
+	        case FE_UPWARD:
+	          return SIGNBIT(a) ? -DBL_MAX : INFINITY;
+	        case FE_TONEAREST:
+	        default:
+	          return SIGNBIT(a) ? -INFINITY : INFINITY;
+	      }
 	  }
-	else if (exp < -BINPOWOF10_LIMIT)		/* Obvious underflow.  */
+	else if (exp <= -POWOF10_MIN_DENORM_DBL_EXP)  /* Obvious underflow.  */
 	  {
 	    if (DFP_EXCEPTIONS_ENABLED)
 	      DFP_HANDLE_EXCEPTIONS (FE_UNDERFLOW|FE_INEXACT);
-	    return SIGNBIT(a) ? -0.0 : 0.0;
+
+	    switch (fegetround())
+	      {
+	        case FE_TONEAREST:
+	          mant = llabs (a_norm);
+	          if (exp < -POWOF10_MIN_DENORM_DBL_EXP
+	              || ((exp == -POWOF10_MIN_DENORM_DBL_EXP)
+	              && (mant >= (POWOF10_MIN_DENORM_DBL_MAN/2LL))))
+	            return SIGNBIT(a) ? -0.0 : 0.0;
+	          else
+	            return SIGNBIT(a) ? -__DBL_DENORM_MIN__ :
+	                                 __DBL_DENORM_MIN__;
+	        case FE_DOWNWARD:
+	          return SIGNBIT(a) ? -__DBL_DENORM_MIN__ : 0.0;
+	        case FE_UPWARD:
+	          return SIGNBIT(a) ? -0.0 : __DBL_DENORM_MIN__;
+	        case FE_TOWARDZERO:
+	        default:
+	          return  SIGNBIT(a) ? -0.0 : 0.0;
+	      }
 	  }
 
 	mant = a_norm;   /* Convert 17 digit mantissa to DI integer.  */
@@ -74,9 +108,5 @@ CONVERT_WRAPPER(
 	    temp /= BINPOWOF10[-sexp];
 	  }
 	result = temp;
-	/* Clear inexact exception raised by DFP arithmetic.  */
-	if (DFP_EXCEPTIONS_ENABLED
-	    && DFP_TEST_EXCEPTIONS (FE_OVERFLOW|FE_UNDERFLOW) == 0)
-	  DFP_CLEAR_EXCEPTIONS (FE_INEXACT);
 )
 hidden_def (PREFIXED_FUNCTION_NAME)
