@@ -1,6 +1,6 @@
 /* Decimal Floating Point function intended to override the libgcc version.
 
-   Copyright (C) 2009-2015 Free Software Foundation, Inc.
+   Copyright (C) 2009-2016 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
@@ -24,8 +24,9 @@
 
 #include <dfpacc.h>
 #include <math.h>
+#include <ieee754r_private.h>
 
-int
+CMPINT
 __BACKEND_(unordsd2) (_Decimal32 x, _Decimal32 y)
 {
   return __isnand64 ((_Decimal64)x) || __isnand64 ((_Decimal64)y);
