@@ -1,7 +1,7 @@
 /* Calculate the cos(x) for a _Decimal32 format x
 
    Copyright (C) 2006 IBM Corporation.
-   Copyright (C) 2007, 2009 Free Software Foundation, Inc.
+   Copyright (C) 2007-2015 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
@@ -50,20 +50,20 @@ IEEE_FUNCTION_NAME (DEC_TYPE x)
 
   FUNC_CONVERT_TO_DN (&x, &dn_x);
 
-  if (___decNumberIsNaN (&dn_x))
+  if (decNumberIsNaN (&dn_x))
     return x+x;
 
-  if (___decNumberIsZero (&dn_x))
+  if (decNumberIsZero (&dn_x))
     return DFP_CONSTANT(1.0);
 
-  if (___decNumberIsInfinite (&dn_x))
+  if (decNumberIsInfinite (&dn_x))
     {
       DFP_EXCEPT (FE_INVALID);
       return DFP_NAN;
     }
 
-  ___decContextDefault (&context, DEFAULT_CONTEXT);
-  ___decNumberCos (&dn_result, &dn_x, &context);
+  decContextDefault (&context, DEFAULT_CONTEXT);
+  decNumberCos (&dn_result, &dn_x, &context);
   FUNC_CONVERT_FROM_DN (&dn_result, &result, &context);
 
   return result;
