@@ -1,7 +1,7 @@
 /* Returns the _Decimal32 value * 2^ the integral value
 
    Copyright (C) 2006 IBM Corporation.
-   Copyright (C) 2007, 2009 Free Software Foundation, Inc.
+   Copyright (C) 2007-2015 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
@@ -81,7 +81,7 @@ IEEE_FUNCTION_NAME (DEC_TYPE x, int y)
     newexp = -INT_MAX;
   dn_x.exponent = newexp;
 
-  ___decContextDefault (&context, DEFAULT_CONTEXT);
+  decContextDefault (&context, DEFAULT_CONTEXT);
   FUNC_CONVERT_FROM_DN (&dn_x, &result, &context);
 
   if (context.status & DEC_Overflow)
