@@ -1,7 +1,7 @@
 /* Returns the unbiased exponent of the passed _Decimal128 value as an
    long int.
 
-   Copyright (C) 2014 Free Software Foundation, Inc.
+   Copyright (C) 2014-2015 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
@@ -25,6 +25,8 @@
 #define FUNCTION_NAME  llogb
 #define _MAX_VALUE     LONG_MAX
 #define _MIN_VALUE     LONG_MIN
+#define _FBLOG0        FP_LLOGB0
+#define _FBLOGNAN      FP_LLOGBNAN
 
 #define _DECIMAL_SIZE  128
 #include <decimal128.h>
