@@ -1,7 +1,7 @@
 /* Returns x * FLT_RADIX^y without computing the right side directly
 
    Copyright (C) 2006 IBM Corporation.
-   Copyright (C) 2007, 2009 Free Software Foundation, Inc.
+   Copyright (C) 2007-2015 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
@@ -53,22 +53,22 @@ IEEE_FUNCTION_NAME (DEC_TYPE x, int y)
 /*  int32_t temp =0; */
 
   FUNC_CONVERT_TO_DN(&x, &dn_x);
-  if (___decNumberIsNaN (&dn_x))
+  if (decNumberIsNaN (&dn_x))
     return x+x;
-  if (___decNumberIsInfinite (&dn_x) || ___decNumberIsZero (&dn_x) || y==0L)
+  if (decNumberIsInfinite (&dn_x) || decNumberIsZero (&dn_x) || y==0L)
     return x;
 
-  ___decContextDefault(&context, DEFAULT_CONTEXT);
+  decContextDefault(&context, DEFAULT_CONTEXT);
 //  sum = dn_x.exponent + y;
 //  if(sum >= 1000000000L || sum <= -2000000000LL)
 //    ; /** definite overflow */
 //  else
 //    dn_x.exponent = sum;
 //
-//  ___decFinalize(&dn_x, &context, &temp, &temp2);
+//  decFinalize(&dn_x, &context, &temp, &temp2);
 
-  ___decNumberFromInt32(&dn_y, y);
-  ___decNumberScaleB(&dn_x, &dn_x, &dn_y, &context);
+  decNumberFromInt32(&dn_y, y);
+  decNumberScaleB(&dn_x, &dn_x, &dn_y, &context);
 
   FUNC_CONVERT_FROM_DN(&dn_x, &result, &context);
   if (context.status & DEC_Overflow)
