@@ -1,7 +1,7 @@
 /* Macros that are used as a set of wrappers for function utilities
 
    Copyright (C) 2006 IBM Corporation.
-   Copyright (C) 2007, 2009 Free Software Foundation, Inc.
+   Copyright (C) 2007-2015 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
@@ -47,8 +47,8 @@
 
 
 
-#if !defined( _DECIMAL_SIZE ) || !defined (FUNCTION_NAME)
-#error Including dfpmacro without defining _DECIMAL_SIZE and FUNCTION_NAME is invalid
+#if !defined( _DECIMAL_SIZE )
+#error Including dfpmacro without defining _DECIMAL_SIZE is invalid
 #endif
 
 #if _DECIMAL_SIZE == 128
@@ -71,13 +71,13 @@
 do {								\
 	PASTE(decimal,SIZE)	decimal;			\
 	PASTE(___host_to_ieee_,SIZE) ((dec), &decimal);		\
-	PASTE(PASTE(___decimal,SIZE),ToNumber) (&decimal,(dn));	\
+	PASTE(PASTE(decimal,SIZE),ToNumber) (&decimal,(dn));	\
 }while (0)
 
 #define FUNC_CONVERT_FROM_DN(dn,dec,context)				\
 do {									\
 	PASTE(decimal,_DECIMAL_SIZE)	decimal;			\
-	PASTE(PASTE(___decimal,_DECIMAL_SIZE),FromNumber)		\
+	PASTE(PASTE(decimal,_DECIMAL_SIZE),FromNumber)		\
 		(&decimal, (dn), (context));				\
 	PASTE(PASTE(___ieee_,_DECIMAL_SIZE),_to_host) (&decimal, (dec));\
 }while(0)
@@ -86,7 +86,7 @@ do {									\
 do {									\
 	PASTE(decimal, _DECIMAL_SIZE)	decimal;			\
 	PASTE(___host_to_ieee_,_DECIMAL_SIZE)(host, &decimal);		\
-	PASTE(___decimal, PASTE(_DECIMAL_SIZE,ToString))		\
+	PASTE(decimal, PASTE(_DECIMAL_SIZE,ToString))		\
 		(&decimal, str);					\
 }while(0)
 
@@ -94,7 +94,7 @@ do {									\
 do {									\
 	PASTE(decimal, _DECIMAL_SIZE)	decimal;			\
 	PASTE(___host_to_ieee_,_DECIMAL_SIZE)(host, &decimal);		\
-	PASTE(___decimal, PASTE(_DECIMAL_SIZE,ToEngString))		\
+	PASTE(decimal, PASTE(_DECIMAL_SIZE,ToEngString))		\
 		(&decimal, str);						\
 }while(0)
 
