@@ -117,9 +117,6 @@ padn (FILE *fp, int pad, int count)
 
 #define PAD(f, c, n) (wide ? wpadn (f, c, n) : padn (f, c, n))
 
-#define size_t     _IO_size_t
-#define FILE	     _IO_FILE
-
 /* Macros for doing the actual output.  */
 
 #define outchar(ch)							      \
@@ -882,7 +879,7 @@ __printf_dfp (FILE *fp,
     PADN (info->pad, width);
 } /* Done output block.  */
 
-   return 0;
+   return done;
 }
 strong_alias (__printf_dfp, printf_dfp)
 hidden_def (__printf_dfp)
