@@ -1,6 +1,6 @@
 /* Decimal Floating Point 64-bit e^x.  POWER6 PowerPC64 version.
 
-   Copyright (C) 2008, 2010 Free Software Foundation, Inc.
+   Copyright (C) 2008-2015 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
@@ -70,7 +70,7 @@ IEEE_FUNCTION_NAME (DEC_TYPE val)
   if (val < DFP_CONSTANT(0.0))
     {
       neg = 1;
-      val = FUNC_D(fabs) (val);
+      val = FUNC_D(__fabs) (val);
     }
 
   tmp = val;
