@@ -1,6 +1,6 @@
 /* Decimal Floating Point 64-bit x^y.  POWER6 PowerPC64 version.
 
-   Copyright (C) 2008 Free Software Foundation, Inc.
+   Copyright (C) 2008-2015 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
@@ -73,7 +73,7 @@ IEEE_FUNCTION_NAME (DEC_TYPE x, DEC_TYPE y)
 	return 1.DD;
       if (y_class == FP_INFINITE && (x_class != FP_NAN))
 	{
-	  DEC_TYPE x_abs = FUNC_D(fabs) (x);
+	  DEC_TYPE x_abs = FUNC_D(__fabs) (x);
 	  if (x == -1.DD)
 	    return 1.DD;
 	  if (y < 0.DD)
@@ -93,7 +93,7 @@ IEEE_FUNCTION_NAME (DEC_TYPE x, DEC_TYPE y)
 	}
       if (x_class == FP_INFINITE && (y_class != FP_NAN))
 	{
-	  DEC_TYPE y_int = FUNC_D(trunc) (y);
+	  DEC_TYPE y_int = FUNC_D(__trunc) (y);
 	  if (y_int == y)
 	    { /* y is an int including 0. */
 	      long long int_y = y_int;
@@ -132,7 +132,7 @@ IEEE_FUNCTION_NAME (DEC_TYPE x, DEC_TYPE y)
 
   /* Split y into integer and fraction and use the identity:
      x ^ (m+n) == ( x^m ) * (x^n) */
-  y_int = FUNC_D(rint) (y);
+  y_int = FUNC_D(__rint) (y);
   y_frac = y - y_int;
 
 #ifdef __DEBUG_PRINT__
@@ -170,7 +170,7 @@ IEEE_FUNCTION_NAME (DEC_TYPE x, DEC_TYPE y)
 	    { /* pole error */
 	      result = HUGE_VAL_D64;
 	      if ( odd_y )
-		result = FUNC_D(copysign) (result, x);
+		result = FUNC_D(__copysign) (result, x);
 	    }
 	  else
 	    result = 1.DD / intpow(x, -int_y);
@@ -194,8 +194,8 @@ IEEE_FUNCTION_NAME (DEC_TYPE x, DEC_TYPE y)
 	  int int_y = y_int; /* convert to int */
 	  DEC_TYPE log_x;
 
-	  log_x = FUNC_D(log) (x);
-	  result = intpow(x, int_y) * FUNC_D(exp) (y_frac * log_x);
+	  log_x = FUNC_D(__log) (x);
+	  result = intpow(x, int_y) * FUNC_D(__exp) (y_frac * log_x);
 	}
     }
 
