@@ -1,4 +1,4 @@
-/*  Copyright (C) 2014-2015 Free Software Foundation, Inc.
+/*  Copyright (C) 2014-2018 Free Software Foundation, Inc.
 
    This file is part of the Decimal Floating Point C Library.
 
@@ -18,65 +18,111 @@
 
    Please see libdfp/COPYING.txt for more information.  */
 
+/* Test flags (e.g. possible exceptions) */
+#define NO_EXTRA_FLAG			0x0
+#define INVALID_EXCEPTION		0x1
+#define OVERFLOW_EXCEPTION		0x4
+#define INEXACT_EXCEPTION		0x10
+#define NO_INEXACT_EXCEPTION		0x200
+#define NO_OVERFLOW_EXCEPTION		0x400
+#define ERRNO_UNCHANGED			0x8000
+#define ERRNO_ERANGE			0x20000
+#define IGNORE_RESULT			0x40000
+#define ONLY_ON_4BYTE_LONG		0x100000
+#define ONLY_ON_8BYTE_LONG		0x200000
+
 
 /* Common setup for an individual test.  */
 #define COMMON_TEST_SETUP(FUNC_NAME, ARG_STR)                           \
   char *test_name;                                                      \
   if (asprintf (&test_name, "%s (%s)", #FUNC_NAME, (ARG_STR)) == -1)    \
-    abort ()
+    abort ();								\
+  feclearexcept (FE_ALL_EXCEPT);					\
+  errno = 0;
 
 /* Common cleanup after an individual test.  */
 #define COMMON_TEST_CLEANUP                     \
   free (test_name)
 
+/* Skip test in case of invalid characteristics.  */
+#define CHECK_SKIP_TEST(EXTRAFLAGS)			\
+  if (((EXTRAFLAGS & ONLY_ON_4BYTE_LONG) != 0		\
+       && sizeof(long int) != 4)			\
+      || ((EXTRAFLAGS & ONLY_ON_8BYTE_LONG) != 0	\
+	  && sizeof(long int) != 8))			\
+    break;
+
+
 /* Run an individual test, including any required setup and checking
    of results, or loop over all tests in an array.  */
-#define RUN_TEST_f_f(FUNC_NAME, ARG_STR, ARG, EXPECTED)                 \
+#define RUN_TEST_f_f(FUNC_NAME, ARG_STR, ARG, EXPECTED, EXTRAFLAGS)	\
   do {                                                                  \
+   CHECK_SKIP_TEST (EXTRAFLAGS);					\
    COMMON_TEST_SETUP (FUNC_NAME, ARG_STR);                              \
-   check_float (test_name, FUNC (FUNC_NAME) (ARG), EXPECTED);           \
+   check_float (test_name, FUNC (FUNC_NAME) (ARG), EXPECTED,		\
+		EXTRAFLAGS);						\
    COMMON_TEST_CLEANUP;                                                 \
   } while (0)
 
-#define RUN_TEST_ff_f(FUNC_NAME, ARG_STR, ARG1, ARG2, EXPECTED)         \
+#define RUN_TEST_ff_f(FUNC_NAME, ARG_STR, ARG1, ARG2, EXPECTED, EXTRAFLAGS) \
   do {                                                                  \
+   CHECK_SKIP_TEST (EXTRAFLAGS);					\
    COMMON_TEST_SETUP (FUNC_NAME, ARG_STR);                              \
-   check_float (test_name, FUNC (FUNC_NAME) (ARG1, ARG2), EXPECTED);    \
+   check_float (test_name, FUNC (FUNC_NAME) (ARG1, ARG2), EXPECTED,	\
+		EXTRAFLAGS);						\
    COMMON_TEST_CLEANUP;                                                 \
   } while (0)
 
-#define RUN_TEST_f_i(FUNC_NAME, ARG_STR, ARG, EXPECTED)                 \
+#define RUN_TEST_f_i(FUNC_NAME, ARG_STR, ARG, EXPECTED, EXTRAFLAGS)	\
   do {                                                                  \
+   CHECK_SKIP_TEST (EXTRAFLAGS);					\
    COMMON_TEST_SETUP (FUNC_NAME, ARG_STR);                              \
-   check_int (test_name, FUNC (FUNC_NAME) (ARG), EXPECTED);             \
+   check_int (test_name, FUNC (FUNC_NAME) (ARG), EXPECTED, EXTRAFLAGS);	\
    COMMON_TEST_CLEANUP;                                                 \
   } while (0)
 
-#define RUN_TEST_f_l(FUNC_NAME, ARG_STR, ARG, EXPECTED)                 \
+#define RUN_TEST_f_l(FUNC_NAME, ARG_STR, ARG, EXPECTED, EXTRAFLAGS)	\
   do {                                                                  \
+   CHECK_SKIP_TEST (EXTRAFLAGS);					\
    COMMON_TEST_SETUP (FUNC_NAME, ARG_STR);                              \
-   check_long (test_name, FUNC (FUNC_NAME) (ARG), EXPECTED);            \
+   check_long (test_name, FUNC (FUNC_NAME) (ARG), EXPECTED,		\
+	       EXTRAFLAGS);						\
    COMMON_TEST_CLEANUP;                                                 \
   } while (0)
 
-#define RUN_TEST_f_L(FUNC_NAME, ARG_STR, ARG, EXPECTED)                 \
+#define RUN_TEST_f_L(FUNC_NAME, ARG_STR, ARG, EXPECTED, EXTRAFLAGS)	\
   do {                                                                  \
+   CHECK_SKIP_TEST (EXTRAFLAGS);					\
    COMMON_TEST_SETUP (FUNC_NAME, ARG_STR);                              \
-   check_longlong (test_name, FUNC (FUNC_NAME) (ARG), EXPECTED);        \
+   check_longlong (test_name, FUNC (FUNC_NAME) (ARG), EXPECTED,		\
+		   EXTRAFLAGS);						\
    COMMON_TEST_CLEANUP;                                                 \
   } while (0)
 
-#define RUN_TEST_ff_b(FUNC_NAME, ARG_STR, ARG1, ARG2,  EXPECTED)        \
+#define RUN_TEST_f_b(FUNC_NAME, ARG_STR, ARG1, EXPECTED, EXTRAFLAGS) \
   do {                                                                  \
+   CHECK_SKIP_TEST (EXTRAFLAGS);					\
    COMMON_TEST_SETUP (FUNC_NAME, ARG_STR);                              \
-   check_bool (test_name, FUNC (FUNC_NAME) (ARG1, ARG2), EXPECTED);     \
+   check_bool (test_name, FUNC (FUNC_NAME) (ARG1), EXPECTED,		\
+	       EXTRAFLAGS);						\
    COMMON_TEST_CLEANUP;                                                 \
   } while (0)
 
-#define RUN_TEST_ff_i(FUNC_NAME, ARG_STR, ARG1, ARG2,  EXPECTED)        \
+#define RUN_TEST_ff_b(FUNC_NAME, ARG_STR, ARG1, ARG2,  EXPECTED, EXTRAFLAGS) \
   do {                                                                  \
+   CHECK_SKIP_TEST (EXTRAFLAGS);					\
    COMMON_TEST_SETUP (FUNC_NAME, ARG_STR);                              \
-   check_int (test_name, FUNC (FUNC_NAME) (ARG1, ARG2), EXPECTED);	\
+   check_bool (test_name, FUNC (FUNC_NAME) (ARG1, ARG2), EXPECTED,	\
+	       EXTRAFLAGS);						\
+   COMMON_TEST_CLEANUP;                                                 \
+  } while (0)
+
+#define RUN_TEST_ff_i(FUNC_NAME, ARG_STR, ARG1, ARG2,  EXPECTED, EXTRAFLAGS) \
+  do {                                                                  \
+   CHECK_SKIP_TEST (EXTRAFLAGS);					\
+   COMMON_TEST_SETUP (FUNC_NAME, ARG_STR);                              \
+   check_int (test_name, FUNC (FUNC_NAME) (ARG1, ARG2), EXPECTED,	\
+	      EXTRAFLAGS);						\
    COMMON_TEST_CLEANUP;                                                 \
   } while (0)
 
@@ -218,14 +264,116 @@ update_stats (int ok)
 #define ULPDIFF(given, expected) \
         (FUNC(fabs) ((given) - (expected)) / ulp (expected))
 
+/* Test whether a given exception was raised.  */
+static void
+test_single_exception (const char *test_name, int exception, int exc_flag,
+		       int fe_flag, const char *flag_name)
+{
+  int ok = 1;
+  if (exception & exc_flag)
+    {
+      if (fetestexcept (fe_flag))
+	{
+	  if (print_screen (1))
+	    printf ("Pass: %s: Exception \"%s\" set\n", test_name, flag_name);
+	}
+      else
+	{
+	  ok = 0;
+	  if (print_screen (0))
+	    printf ("Failure: %s: Exception \"%s\" not set\n",
+		    test_name, flag_name);
+	}
+    }
+  else
+    {
+      if (fetestexcept (fe_flag))
+	{
+	  ok = 0;
+	  if (print_screen (0))
+	    printf ("Failure: %s: Exception \"%s\" set\n",
+		    test_name, flag_name);
+	}
+      else
+	{
+	  if (print_screen (1))
+	    printf ("%s: Exception \"%s\" not set\n", test_name,
+		    flag_name);
+	}
+    }
+  if (!ok)
+    ++noErrors;
+}
+
+static void
+test_exceptions (const char *test_name, int exception)
+{
+#ifdef FE_INEXACT
+  if ((exception & (INEXACT_EXCEPTION | NO_INEXACT_EXCEPTION)) != 0)
+    test_single_exception (test_name, exception, INEXACT_EXCEPTION,
+			   FE_INEXACT, "Inexact");
+#endif
+#ifdef FE_INVALID
+      if ((exception & INVALID_EXCEPTION) != 0)
+	test_single_exception (test_name, exception,
+			       INVALID_EXCEPTION, FE_INVALID,
+			       "Invalid");
+#endif
+#ifdef FE_OVERFLOW
+      if ((exception & (OVERFLOW_EXCEPTION  | NO_OVERFLOW_EXCEPTION)) != 0)
+	test_single_exception (test_name, exception,
+			       OVERFLOW_EXCEPTION, FE_OVERFLOW,
+			       "Overflow");
+#endif
+}
+
+/* Test whether errno for TEST_NAME, set to ERRNO_VALUE, has value
+   EXPECTED_VALUE (description EXPECTED_NAME).  */
+static void
+test_single_errno (const char *test_name, int errno_value,
+		   int expected_value, const char *expected_name)
+{
+  if (errno_value == expected_value)
+    {
+      if (print_screen (1))
+	printf ("Pass: %s: errno set to %d (%s)\n", test_name, errno_value,
+		expected_name);
+    }
+  else
+    {
+      ++noErrors;
+      if (print_screen (0))
+	printf ("Failure: %s: errno set to %d, expected %d (%s)\n",
+		test_name, errno_value, expected_value, expected_name);
+    }
+}
+
+/* Test whether errno (value ERRNO_VALUE) has been for TEST_NAME set
+   as required by EXCEPTIONS.  */
+static void
+test_errno (const char *test_name, int errno_value, int exceptions)
+{
+  if (exceptions & ERRNO_UNCHANGED)
+    test_single_errno (test_name, errno_value, 0, "unchanged");
+  if (exceptions & ERRNO_ERANGE)
+    test_single_errno (test_name, errno_value, ERANGE, "ERANGE");
+}
+
 static void
 __attribute__((used))
-check_float (const char *test_name, FLOAT computed, FLOAT expected)
+check_float (const char *test_name, FLOAT computed, FLOAT expected,
+	     int extraflags)
 {
   int ok = 0;
   int print_diff = 0;
   FLOAT diff = 0;
   FLOAT ulps = 0;
+  int errno_value = errno;
+
+  test_exceptions (test_name, extraflags);
+  test_errno (test_name, errno_value, extraflags);
+  if (extraflags & IGNORE_RESULT)
+    goto out;
 
   FLOAT max_ulp = find_test_ulps (test_name);
   if (issignaling (computed) && issignaling (expected))
@@ -279,16 +427,22 @@ check_float (const char *test_name, FLOAT computed, FLOAT expected)
     }
   update_stats (ok);
 
+ out:
   errno = 0;
 }
 
 /* Check that computed and expected values are equal (int values).  */
 static void
 __attribute__((used))
-check_int (const char *test_name, int computed, int expected)
+check_int (const char *test_name, int computed, int expected, int extraflags)
 {
   int ok = 0;
+  int errno_value = errno;
 
+  test_exceptions (test_name, extraflags);
+  test_errno (test_name, errno_value, extraflags);
+  if (extraflags & IGNORE_RESULT)
+    goto out;
   noTests++;
   if (computed == expected)
     ok = 1;
@@ -304,17 +458,23 @@ check_int (const char *test_name, int computed, int expected)
     }
 
   update_stats (ok);
+ out:
   errno = 0;
 }
 
 /* check that computed and expected values are equal (long int values) */
 static void
 __attribute__((used))
-check_long (const char *test_name, long int computed,
-            long int expected)
+check_long (const char *test_name, long int computed, long int expected,
+	    int extraflags)
 {
   int ok = 0;
+  int errno_value = errno;
 
+  test_exceptions (test_name, extraflags);
+  test_errno (test_name, errno_value, extraflags);
+  if (extraflags & IGNORE_RESULT)
+    goto out;
   noTests++;
   if (computed == expected)
     ok = 1;
@@ -330,16 +490,23 @@ check_long (const char *test_name, long int computed,
     }
 
   update_stats (ok);
+ out:
+  errno = 0;
 }
 
 /* check that computed and expected values are equal (long int values) */
 static void
 __attribute__((used))
 check_longlong (const char *test_name, long long int computed,
-                long long int expected)
+		long long int expected, int extraflags)
 {
   int ok = 0;
+  int errno_value = errno;
 
+  test_exceptions (test_name, extraflags);
+  test_errno (test_name, errno_value, extraflags);
+  if (extraflags & IGNORE_RESULT)
+    goto out;
   noTests++;
   if (computed == expected)
     ok = 1;
@@ -355,15 +522,22 @@ check_longlong (const char *test_name, long long int computed,
     }
 
   update_stats (ok);
+ out:
+  errno = 0;
 }
 
 /* Check that computed value is true/false.  */
 static void
 __attribute__((used))
-check_bool (const char *test_name, int computed, int expected)
+check_bool (const char *test_name, int computed, int expected, int extraflags)
 {
   int ok = 0;
+  int errno_value = errno;
 
+  test_exceptions (test_name, extraflags);
+  test_errno (test_name, errno_value, extraflags);
+  if (extraflags & IGNORE_RESULT)
+    goto out;
   noTests++;
   if ((computed == 0) == (expected == 0))
     ok = 1;
@@ -379,4 +553,6 @@ check_bool (const char *test_name, int computed, int expected)
     }
 
   update_stats (ok);
+ out:
+  errno = 0;
 }
