@@ -214,19 +214,19 @@ typedef struct{
 
 dddf_type dddf_tests[] =
 {
-  {__LINE__, -7.0DD, -7.0,  "%De"},
-  {__LINE__, 3.402819e+38DD, 3.402819e+38,  "%De"},
-  {__LINE__, 1.79768e+308DD, 1.79768e+308,  "%De"},
-  {__LINE__, 100000000000000.0DD, 100000000000000,  "%De"},
-  {__LINE__, 999999999999999.0DD, 999999999999999,  "%De"},
-  {__LINE__, 1.e290DD, 1.e290,  "%De"},
-  {__LINE__, 1.e291DD, 1.e291,  "%De"},
-  {__LINE__, 1.e308DD, 1.e308,  "%De"},
-  {__LINE__, 1.e-308DD, 1.e-308,  "%De"},
-  {__LINE__, 1.e-291DD, 1.e-291,  "%De"},
-  {__LINE__, 1.e-290DD, 1.e-290,  "%De"},
-  {__LINE__, 1.e-39DD, 1.e-39,  "%De"},
-  {__LINE__, -1.e-39DD, -1.e-39,  "%De"},
+  {__LINE__, -7.0DD, -7.0,  "%e"},
+  {__LINE__, 3.402819e+38DD, 3.402819e+38,  "%e"},
+  {__LINE__, 1.79768e+308DD, 1.79768e+308,  "%e"},
+  {__LINE__, 100000000000000.0DD, 100000000000000,  "%e"},
+  {__LINE__, 999999999999999.0DD, 999999999999999,  "%e"},
+  {__LINE__, 1.e290DD, 1.e290,  "%e"},
+  {__LINE__, 1.e291DD, 1.e291,  "%e"},
+  {__LINE__, 1.e308DD, 1.e308,  "%e"},
+  {__LINE__, 1.e-308DD, 1.e-308,  "%e"},
+  {__LINE__, 1.e-291DD, 1.e-291,  "%e"},
+  {__LINE__, 1.e-290DD, 1.e-290,  "%e"},
+  {__LINE__, 1.e-39DD, 1.e-39,  "%e"},
+  {__LINE__, -1.e-39DD, -1.e-39,  "%e"},
   {0,0,0,0 }
 };
 
@@ -320,27 +320,27 @@ typedef struct{
   long double e;/* tf 'long double float' converted value.  */
   double ppce1; /* df 'double float' part of the expected value for IBM long double. */
   double ppce2; /* df 'double float' part of the expected value for IBM long double. */
-  const char *format; /* printf %DDe */
+  const char *format; /* printf %Le */
 } tdtf_type;
 
 tdtf_type tdtf_tests[] =
 {
-  {__LINE__, 30.0DL, 30.0, 30, 0, "%DDe"},
+  {__LINE__, 30.0DL, 30.0, 30, 0, "%Le"},
   /* 2**(-11) = 0.00048828125. */
-  {__LINE__, 0.00048828125DL, 0.00048828125L, 0.00048828125, 0, "%DDe"},
+  {__LINE__, 0.00048828125DL, 0.00048828125L, 0.00048828125, 0, "%Le"},
   /* 2**(-25) = 0.298023223876953125E-7.  */
-  {__LINE__, 2.98023223876953125E-8DL, 2.98023223876953125E-8, 2.9802322387695312e-08, 0, "%DDe"},
-  {__LINE__, 3.402819e+38DL, 3.402819e+38L, 3.4028189999999998e+38, 1.7176206731396606e+22, "%DDe"},
-  {__LINE__, 100000000000000000.0DL, 100000000000000000, 1e+17, 0, "%DDe"},
-  {__LINE__, 999999999999999999.0DL, 999999999999999999, 1e+18, -1, "%DDe"},
-  {__LINE__, 100000000000000000000000000000000.0DL, 100000000000000000000000000000000.L, 1.0000000000000001e+32, -5366162204393472, "%DDe"},
-  {__LINE__, 999999999999999999999999999999999.0DL, 999999999999999999999999999999999.L, 9.9999999999999995e+32, 54424769012957184, "%DDe"},
-  {__LINE__, 1.e290DL, 1.e290L, 1.0000000000000001e+290, -6.1727833527867157e+273, "%DDe"},
-  {__LINE__, 1.e-290DL, 1.e-290L, 1.0000000000000001e-290, -6.9127868599625479e-307, "%DDe"},
-  {__LINE__, 1.e-308DL, 1.e-308L, 9.9999999999999991e-309, 0, "%DDe"},
-  {__LINE__, 1.e-291DL, 1.e-291L, 9.9999999999999996e-292, 3.7675676608720188e-308, "%DDe"},
-  {__LINE__, 3.e-309DL, 3.e-309L, 3.0000000000000007e-309, 0, "%DDe"},
-  {__LINE__, -3.e-309DL, -3.e-309L, -3.0000000000000007e-309, 0, "%DDe"},
+  {__LINE__, 2.98023223876953125E-8DL, 2.98023223876953125E-8, 2.9802322387695312e-08, 0, "%Le"},
+  {__LINE__, 3.402819e+38DL, 3.402819e+38L, 3.4028189999999998e+38, 1.7176206731396606e+22, "%Le"},
+  {__LINE__, 100000000000000000.0DL, 100000000000000000, 1e+17, 0, "%Le"},
+  {__LINE__, 999999999999999999.0DL, 999999999999999999, 1e+18, -1, "%Le"},
+  {__LINE__, 100000000000000000000000000000000.0DL, 100000000000000000000000000000000.L, 1.0000000000000001e+32, -5366162204393472, "%Le"},
+  {__LINE__, 999999999999999999999999999999999.0DL, 999999999999999999999999999999999.L, 9.9999999999999995e+32, 54424769012957184, "%Le"},
+  {__LINE__, 1.e290DL, 1.e290L, 1.0000000000000001e+290, -6.1727833527867157e+273, "%Le"},
+  {__LINE__, 1.e-290DL, 1.e-290L, 1.0000000000000001e-290, -6.9127868599625479e-307, "%Le"},
+  {__LINE__, 1.e-308DL, 1.e-308L, 9.9999999999999991e-309, 0, "%Le"},
+  {__LINE__, 1.e-291DL, 1.e-291L, 9.9999999999999996e-292, 3.7675676608720188e-308, "%Le"},
+  {__LINE__, 3.e-309DL, 3.e-309L, 3.0000000000000007e-309, 0, "%Le"},
+  {__LINE__, -3.e-309DL, -3.e-309L, -3.0000000000000007e-309, 0, "%Le"},
   {0,0,0,0,0,0 }
 };
 
